name: Release New Version

on:
  push:
    tags:
      - 'v*' # Trigger on tags starting with 'v'

jobs:
  release:
    runs-on: ubuntu-latest

    steps:
      - name: Check out code
        uses: actions/checkout@v2

      - name: Setup PHP
        uses: shivammathur/setup-php@v2
        with:
          php-version: '7.4' # Use the desired PHP version

      - name: Install Composer dependencies
        run: composer install --no-dev --prefer-dist --optimize-autoloader --no-interaction

      - name: Create Release
        id: create_release
        uses: softprops/action-gh-release@v1
        with:
          files: |
            builds/moneroo-$VERSION.zip # Replace with the actual path to your plugin ZIP file
          draft: false
          prerelease: false
        env:
          GITHUB_TOKEN: ${{ secrets.GITHUB_TOKEN }}

      - name: Publish to WordPress SVN
        run: |
          PLUGIN="moneroo"
          PROJECT_ROOT=$(pwd)
          PLUGIN_BUILDS_PATH="$PROJECT_ROOT/builds"
          PLUGIN_BUILD_CONFIG_PATH="$PROJECT_ROOT/build-cfg"
          VERSION=$(awk 'NR==7' readme.txt | cut -d ' ' -f 3)
          ZIP_FILE="$PLUGIN_BUILDS_PATH/$PLUGIN-$VERSION.zip"

          mkdir -p $PLUGIN_BUILDS_PATH
          zip -r $ZIP_FILE . -x "deploy/*" "build-cfg/*" "builds/*" ".*" "wp-assets/*"

          if [ ! -f "$ZIP_FILE" ]; then
              echo "Built zip file $ZIP_FILE does not exist" 1>&2
              exit 1
          fi

          cd "$PLUGIN_BUILDS_PATH"
          rm -fR "$PLUGIN"
          unzip -q -o "$ZIP_FILE" -d $PLUGIN
          rm -fR svn
          svn co -q "http://svn.wp-plugins.org/$PLUGIN" svn
          mv svn/trunk ./svn-trunk
          mkdir svn/trunk
          rsync -r -p $PLUGIN/* svn/trunk

          cd svn/trunk/
          TARGET=$(pwd)
          cd ../../svn-trunk/
          SVN_DIRS=$(find . -type d -iname .svn)

          for SVN_DIR in $SVN_DIRS; do
              SOURCE_DIR=${SVN_DIR/.}
              TARGET_DIR=$TARGET${SOURCE_DIR/.svn}
              TARGET_SVN_DIR=$TARGET${SVN_DIR/.}
              if [ -d "$TARGET_DIR" ]; then
                  cp -r $SVN_DIR $TARGET_SVN_DIR
              fi
          done

          cd ../
          rm -fR svn-trunk
          mkdir svn/tags/$VERSION
          rsync -r -p $PLUGIN/* svn/tags/$VERSION
          svn stat svn | grep '^?' | awk '{print $2}' | xargs -I x svn add x@
          svn stat svn | grep '^!' | awk '{print $2}' | xargs -I x svn rm --force x@
          svn stat svn

          svn ci --no-auth-cache --username $SVN_USERNAME --password $SVN_PASSWORD svn -m "Deploy version $VERSION"
          rm -fR svn
        env:
          SVN_USERNAME: ${{ secrets.SVN_USERNAME }}
          SVN_PASSWORD: ${{ secrets.SVN_PASSWORD }}
